X-Git-Url: https://git.rapsys.eu/packbundle/blobdiff_plain/4ab8e94003e0d50e0b4e9c74c8bd4fb0d45bf7b4..3368f7c8af4706ab309544d8710e724e8b5f0ee8:/RapsysPackBundle.php

diff --git a/RapsysPackBundle.php b/RapsysPackBundle.php
index 67b26ce..d53a591 100644
--- a/RapsysPackBundle.php
+++ b/RapsysPackBundle.php
@@ -11,19 +11,29 @@
 
 namespace Rapsys\PackBundle;
 
-use Symfony\Component\DependencyInjection\Container;
+use Rapsys\PackBundle\DependencyInjection\RapsysPackExtension;
+
+use Symfony\Component\DependencyInjection\Extension\ExtensionInterface;
 use Symfony\Component\HttpKernel\Bundle\Bundle;
 
 /**
  * {@inheritdoc}
  */
 class RapsysPackBundle extends Bundle {
+	/**
+	 * {@inheritdoc}
+	 */
+	public function getContainerExtension(): ?ExtensionInterface {
+		//Return created container extension
+		return $this->createContainerExtension();
+	}
+
 	/**
 	 * Return bundle alias
 	 *
 	 * @return string The bundle alias
 	 */
-    public static function getAlias(): string {
+	public static function getAlias(): string {
 		//With namespace
 		if ($npos = strrpos(static::class, '\\')) {
 			//Set name pos
@@ -43,7 +53,17 @@ class RapsysPackBundle extends Bundle {
 			$bpos = strlen(static::class) - $npos;
 		}
 
-		//Return underscored lowercase bundle alias
-		return Container::underscore(substr(static::class, $npos, $bpos));
-    }
+		//Return lowercase bundle alias
+		return strtolower(substr(static::class, $npos, $bpos));
+	}
+
+	/**
+	 * Return bundle version
+	 *
+	 * @return string The bundle version
+	 */
+	public static function getVersion(): string {
+		//Return version
+		return '0.5.1';
+	}
 }